EgyptID class

Inheritance

Constructors

EgyptID()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculateAge(String id) Age
override
extractBirthDate(String id) String
override
extractGender(String id) String
override
extractGovernorate(String id) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited