sendEmailVerification method
Sends a verification email to the current user. Throws if no user is signed in or the request fails.
Implementation
Future<void> sendEmailVerification() async =>
await currentUser!.sendEmailVerification();
Sends a verification email to the current user. Throws if no user is signed in or the request fails.
Future<void> sendEmailVerification() async =>
await currentUser!.sendEmailVerification();