init method
Must be called once before using any other method.
Safe to call multiple times – subsequent calls are no-ops.
Implementation
Future<void> init() async {
_prefs ??= await SharedPreferences.getInstance();
}
Must be called once before using any other method.
Safe to call multiple times – subsequent calls are no-ops.
Future<void> init() async {
_prefs ??= await SharedPreferences.getInstance();
}