CryptoException class

Exception thrown by any operation in crypto_kit.

Implemented types

Constructors

CryptoException({required String message, Object? cause, StackTrace? stackTrace})
const

Properties

cause Object?
The original exception that triggered this error, if any.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of what went wrong.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The original stack trace, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited