iterations property
The PBKDF2 iteration count used.
Stored inside combined so PasswordHasher.verify can reproduce the exact derivation even after you raise the default iteration count.
Implementation
final int iterations;
The PBKDF2 iteration count used.
Stored inside combined so PasswordHasher.verify can reproduce the exact derivation even after you raise the default iteration count.
final int iterations;