canPop static method
Returns true if there is a route that can be popped.
Implementation
static bool canPop(BuildContext context) => Navigator.canPop(context);
Returns true if there is a route that can be popped.
static bool canPop(BuildContext context) => Navigator.canPop(context);