builders property
Maps route names → widget builders.
The builder receives the caller's original arguments (transition metadata is stripped before the builder is called).
Implementation
final Map<String, Widget Function(Object? arguments)> builders;
Maps route names → widget builders.
The builder receives the caller's original arguments (transition metadata is stripped before the builder is called).
final Map<String, Widget Function(Object? arguments)> builders;