BaiomyLogger class

Constructors

BaiomyLogger()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BaiomyLogger
no setter

Static Methods

debug(String message) → void
error(String message, {Object? error, StackTrace? stackTrace}) → void
info(String message) → void
log(String message) → void
success(String message) → void
warning(String message) → void