BaiomyToast class

Constructors

BaiomyToast()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

error(BuildContext context, String message, {Duration duration = const .new(seconds: 4), ToastPosition position = .bottom}) → void
Show error toast
hide() → void
Hide current toast
hideAll() → void
Hide all toasts
hideLoading() → void
Hide loading toast
info(BuildContext context, String message, {Duration duration = const .new(seconds: 3), ToastPosition position = .top}) → void
Show info toast
loading(BuildContext context, String message, {ToastPosition position = .center}) → void
Show loading toast (doesn't auto-dismiss)
success(BuildContext context, String message, {Duration duration = const .new(seconds: 3), ToastPosition position = .top}) → void
Show success toast
warning(BuildContext context, String message, {Duration duration = const .new(seconds: 3), ToastPosition position = .top}) → void
Show warning toast