NavTransitions class
Builds animated page transitions and provides default durations.
You typically won't call this directly – it is used internally by
NavRouteGenerator and NavKit.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
build(
NavTransitionType type, BuildContext context, Animation< double> animation, Animation<double> secondaryAnimation, Widget child) → Widget -
Constructs the transition widget for the given
type. -
defaultDuration(
NavTransitionType type) → Duration - Default forward-transition duration for each NavTransitionType.
-
defaultReverseDuration(
NavTransitionType type) → Duration - Default reverse-transition duration for each NavTransitionType.